/* wptW32API.h - Common API interface
 *	Copyright (C) 2001-2009 Timo Schulz
 *
 * This file is part of WinPT.
 *
 * WinPT is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 
 * as published by the Free Software Foundation; either version 2 
 * of the License, or (at your option) any later version.
 *  
 * WinPT is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 */

#ifndef WPT_W32_API_H
#define WPT_W32_API_H

/* Macros to change the cursor */
#define op_begin()  SetCursor (LoadCursor (NULL, IDC_WAIT))
#define op_end()    SetCursor (LoadCursor (NULL, IDC_ARROW))

#include "wptCrypto.h"
#include "wptUtil.h"

/*-- wptMAPI.cpp --*/
int mapi_init (void);
int mapi_send_pubkey (const char *keyid, char *keyfile);
int mapi_send_ascfile (char *ascfile);
void mapi_deinit (void);

/*-- wptSafeEditCtrl.cpp --*/
UINT SafeGetDlgItemText (HWND dlg, int id, char *buf, int buflen);
void safe_edit_control_init (HWND dlg, int ctlid);
void safe_edit_control_free (HWND dlg, int ctlid);

/*-- wptW32API.cpp --*/
char* make_filename (const char *path, const char *file, const char *ext);
char* make_special_filename (int folder, const char *file, const char *ext);
int file_exist_check (const char *fname);
int dir_exist_check (const char *dir);
DWORD get_file_size (const char *fname);
int get_file_version (const char *fname, WORD *major, WORD *minor, 
		      WORD *patch1, WORD *patch2);

int copy_window_content (HWND old, HWND *r_main, HWND *r_focus, 
			 int use_hotkey);
int paste_window_content (HWND old, HWND main, HWND focus);

void center_window (HWND hwndChild, HWND hwndParent);
void center_window2 (HWND hwndChild, HWND parent, HWND style);
void force_foreground_window (HWND dlg, int msecs);

void insert_menu_item (HMENU hm, int by_pos, UINT m_id, const char *text);
void set_menu_text (HMENU menu, UINT m_uid, const char *text);
void set_menu_text_bypos (HMENU menu, UINT pos, const char *text);
void set_menu_state (HMENU menu, UINT m_uid, UINT state);
UINT get_menu_state (HMENU menu, UINT m_uid);

char* get_clip_text (HWND hwnd);
int set_clip_text (HWND hwnd, const char *text, int nbytes);
int set_clip_text2 (HWND hwnd, const char *text, int nbytes, int as_footer);
int dialog_box_param( HINSTANCE hinst, LPCTSTR name, HWND parent, DLGPROC fnc,
		     LPARAM param, LPCTSTR title, int title_id );
int msg_box( HWND hwnd, const char *text, const char *title, int mode );
int check_date( SYSTEMTIME *st );
const char* get_filesave_dlg (HWND hwnd, const char *title,
			      const char *filter, const char *name);
const char* get_fileopen_dlg (HWND hwnd, const char *title,
			      const char *filter, const char *name);
const char * get_folder_dlg( HWND hwnd, const char * title, const char * name );
char * m_strdup (const char *str);
const char* get_locale_date (long tm_t, char *buf, DWORD buflen);
const char* get_locale_time (long tm_t, char *buf, DWORD buflen);
const char* get_locale_timedate (long tm_t, char *buf, DWORD buflen);
int get_temp_name (char *buf, DWORD buflen, const char *name);

int GetDlgItemText_utf8 (HWND dlg, int id, char **r_txt);
BOOL user_is_admin (void);

#define listbox_add_string(lb, string) \
    SendMessage( (lb), LB_ADDSTRING, 0, (LPARAM)(LPCSTR)(string) )

#define listbox_get_cursel(lb) \
    SendMessage( (lb), LB_GETCURSEL, 0, 0 )

#define combox_add_string(cb, string) \
    SendMessage( (cb), CB_ADDSTRING, 0, (LPARAM)(LPCSTR)(string) )

#define item_get_text_length(dlg, itm) \
	SendDlgItemMessage ((dlg), (itm), WM_GETTEXTLENGTH, 0, 0)

int html_help_show (int map_id);
#ifdef _MSC_VER
#include <htmlhelp.h>

#define html_help_init(cookie) \
    HtmlHelp (NULL, NULL, HH_INITIALIZE, (DWORD)(cookie))

#define html_help_deinit(cookie) \
    HtmlHelp (NULL, NULL, HH_UNINITIALIZE, (DWORD)(cookie))

#define html_help_dispatch(param, file, helparr) do { \
    HELPINFO *inf; \
    inf = (HELPINFO *)param; \
    if (inf->iContextType == HELPINFO_WINDOW) \
	HtmlHelp ((HWND)inf->hItemHandle, file, \
		   HH_TP_HELP_CONTEXTMENU, (DWORD)helparr); \
    } while (0)
#else
#define html_help_init(cookie) do {} while (0)
#define html_help_deinit(cookie) do { (cookie) = 0; } while (0)
#define html_help_dispatch(param, file, helparr) do {} while (0)
#endif

#endif /* WPT_W32_API_H */
